==> Pyrogram-2.0.1-py3-none-any.whl: pyrogram/raw/functions/contacts/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .get_contact_i_ds import GetContactIDs
from .get_statuses import GetStatuses
from .get_contacts import GetContacts
from .import_contacts import ImportContacts
from .delete_contacts import DeleteContacts
from .delete_by_phones import DeleteByPhones
from .block import Block
from .unblock import Unblock
from .get_blocked import GetBlocked
from .search import Search
from .resolve_username import ResolveUsername
from .get_top_peers import GetTopPeers
from .reset_top_peer_rating import ResetTopPeerRating
from .reset_saved import ResetSaved
from .get_saved import GetSaved
from .toggle_top_peers import ToggleTopPeers
from .add_contact import AddContact
from .accept_contact import AcceptContact
from .get_located import GetLocated
from .block_from_replies import BlockFromReplies
from .resolve_phone import ResolvePhone

==> Pyrogram-2.0.68-py3-none-any.whl: pyrogram/raw/functions/contacts/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .get_contact_i_ds import GetContactIDs
from .get_statuses import GetStatuses
from .get_contacts import GetContacts
from .import_contacts import ImportContacts
from .delete_contacts import DeleteContacts
from .delete_by_phones import DeleteByPhones
from .block import Block
from .unblock import Unblock
from .get_blocked import GetBlocked
from .search import Search
from .resolve_username import ResolveUsername
from .get_top_peers import GetTopPeers
from .reset_top_peer_rating import ResetTopPeerRating
from .reset_saved import ResetSaved
from .get_saved import GetSaved
from .toggle_top_peers import ToggleTopPeers
from .add_contact import AddContact
from .accept_contact import AcceptContact
from .get_located import GetLocated
from .block_from_replies import BlockFromReplies
from .resolve_phone import ResolvePhone
from .export_contact_token import ExportContactToken
from .import_contact_token import ImportContactToken
